package WebGUI::i18n::Dutch::Shop;
use utf8;
our $I18N = {
  'Add new address' => {
    'lastUpdated' => '1274107814',
    'message' => 'Voeg een adres toe'
  },
  'Backordered' => {
    'lastUpdated' => '1216732041',
    'message' => 'Niet voorradig'
  },
  'Billing Address' => {
    'lastUpdated' => '1274107823',
    'message' => 'Factuuradres'
  },
  'Cancelled' => {
    'lastUpdated' => '1213631836',
    'message' => 'Geannuleerd'
  },
  'Choose a payment gateway and update the cart to checkout' => {
    'lastUpdated' => '1274107971',
    'message' => 'Kies een betalingsmethode en vernieuw om af te rekenen.'
  },
  'Choose a payment method' => {
    'lastUpdated' => '1274107835',
    'message' => 'Kies een betalingsmethode'
  },
  'Choose a shipping method' => {
    'lastUpdated' => '1254902568',
    'message' => 'Kies een verzendmethode'
  },
  'Choose a shipping method and update the cart to checkout' => {
    'lastUpdated' => '1254902601',
    'message' => 'Kies een verzendmethode en vernieuw de winkelwagen om af te rekenen.'
  },
  'Failed' => {
    'lastUpdated' => '1256112986',
    'message' => 'Mislukt'
  },
  'No shippers' => {
    'lastUpdated' => '1251885498',
    'message' => 'Er zijn geen verzendopties geconfigureerd. Gebruikers kunnen hun bestelling niet voltooien tenzij er minimaal een optie is geconfigureerd.'
  },
  'No shipping plugins configured' => {
    'lastUpdated' => '1251885532',
    'message' => 'Geen verzendopties geconfigureerd. Informeer alstublieft de beheerder.'
  },
  'NotShipped' => {
    'lastUpdated' => '1213968493',
    'message' => 'Niet verzonden'
  },
  'Payment Information' => {
    'lastUpdated' => '1218986043',
    'message' => 'Betalingsinformatie'
  },
  'Preferred Payment Type' => {
    'lastUpdated' => '1218986059',
    'message' => 'Voorkeur betalingsmethode'
  },
  'Shipped' => {
    'lastUpdated' => '1213968499',
    'message' => 'Verzonden'
  },
  'Shipping Address' => {
    'lastUpdated' => '1274108018',
    'message' => 'Verzendadres'
  },
  'Special shipping' => {
    'lastUpdated' => '1274108029',
    'message' => 'Speciaal verzenden'
  },
  'Status' => {
    'lastUpdated' => '1256112991',
    'message' => 'Status'
  },
  'Success' => {
    'lastUpdated' => '1256112997',
    'message' => 'Succes'
  },
  'Update %s' => {
    'lastUpdated' => '1274108054',
    'message' => 'Adres bijwerken: %s'
  },
  'add a new address' => {
    'lastUpdated' => '1213631850',
    'message' => 'Voeg een nieuw adres toe'
  },
  'add a vendor' => {
    'lastUpdated' => '1216652784',
    'message' => 'Voeg een verkooppunt toe'
  },
  'add credit message' => {
    'lastUpdated' => '1216652831',
    'message' => '%s was toegevoegd aan het winkel krediet van %s, voor een totaal krediet van %s.'
  },
  'add payment method' => {
    'lastUpdated' => '1216652847',
    'message' => 'Voeg betalingsmethode toe'
  },
  'add shipper' => {
    'lastUpdated' => '1216652860',
    'message' => 'Voeg verzendmethode toe'
  },
  'add to cart' => {
    'lastUpdated' => '1213968400',
    'message' => 'Toevoegen aan winkelwagen'
  },
  'addButton help' => {
    'lastUpdated' => '1216652928',
    'message' => 'Een knop waarmee de gebruiker een nieuw adres kan toevoegen.'
  },
  'address' => {
    'lastUpdated' => '1213968509',
    'message' => 'Adres'
  },
  'address book template' => {
    'lastUpdated' => '1215445882',
    'message' => 'Adresboek sjabloon'
  },
  'address book template help' => {
    'lastUpdated' => '1216653103',
    'message' => 'Dit sjabloon bepaalt hoe het adresboek eruit zal zien.'
  },
  'address help' => {
    'lastUpdated' => '1216652959',
    'message' => 'Een adres in HTML.'
  },
  'address labelField help' => {
    'lastUpdated' => '1216719103',
    'message' => 'Een veld dat een label van het adres bevat zoals &quot;thuis&quot; of &quot;werk&quot;.'
  },
  'address loop help' => {
    'lastUpdated' => '1216653373',
    'message' => 'Een functie die een lijst bevat met alle adressen in dit adresboek bevat met beheerknoppen.'
  },
  'address nameField help' => {
    'lastUpdated' => '1216719395',
    'message' => 'Een veld dat de naam van de persoon of het bedrijf bevat dat hoort bij dit adres.'
  },
  'address1 help' => {
    'lastUpdated' => '1216652979',
    'message' => 'De eerste regel van het adres.'
  },
  'address1Field help' => {
    'lastUpdated' => '1216653042',
    'message' => 'Het veld voor de eerste adresregel.'
  },
  'address2 help' => {
    'lastUpdated' => '1216652993',
    'message' => 'De tweede regel van het adres.<br /> '
  },
  'address2Field help' => {
    'lastUpdated' => '1216653065',
    'message' => 'Het veld voor de tweede adresregel.'
  },
  'address3 help' => {
    'lastUpdated' => '1216653004',
    'message' => 'De derde regel van het adres.<br /> '
  },
  'address3Field help' => {
    'lastUpdated' => '1216653075',
    'message' => 'Het veld voor de derde adresregel.'
  },
  'addresses loop help' => {
    'lastUpdated' => '1216653385',
    'message' => 'Een functie die een lijst bevat met alle adressen in dit adresboek bevat.'
  },
  'amount' => {
    'lastUpdated' => '1213968384',
    'message' => 'Bedrag'
  },
  'amount help' => {
    'lastUpdated' => '1213970556',
    'message' => 'Het totale bedrag van deze transactie, met twee decimalen.'
  },
  'available' => {
    'lastUpdated' => '1213631824',
    'message' => 'Beschikbaar'
  },
  'billing address1' => {
    'lastUpdated' => '1274108180',
    'message' => 'Vul de straatnaam en huisnummer van het factuuradres in.'
  },
  'billing city' => {
    'lastUpdated' => '1274108110',
    'message' => 'Kies de stad voor het factuuradres.'
  },
  'billing code' => {
    'lastUpdated' => '1274108149',
    'message' => 'Vul de postcode in voor het factuuradres.'
  },
  'billing country' => {
    'lastUpdated' => '1274108143',
    'message' => 'Vul het land in voor het factuuradres.'
  },
  'billing firstName' => {
    'lastUpdated' => '1274108200',
    'message' => 'Vul de voornaam in voor het factuuradres.'
  },
  'billing label' => {
    'lastUpdated' => '1274108217',
    'message' => 'Vul een referentie in voor het factuuradres.'
  },
  'billing lastName' => {
    'lastUpdated' => '1274108228',
    'message' => 'Vul de achternaam in voor het factuuradres.'
  },
  'billing phoneNumber' => {
    'lastUpdated' => '1274108244',
    'message' => 'Vul het telefoonnummer in voor het factuuradres.'
  },
  'billing state' => {
    'lastUpdated' => '1274108258',
    'message' => 'Vul de staat of provincie in voor het factuuradres.'
  },
  'billingAddressChooser help' => {
    'lastUpdated' => '1278062332',
    'message' => 'Een dropdown menu om een factuuradres te kiezen.'
  },
  'biweekly' => {
    'lastUpdated' => '1213968466',
    'message' => 'Twee weken'
  },
  'cancel recurring transaction' => {
    'lastUpdated' => '1216653409',
    'message' => 'Terugkerende transactiesa annuleren'
  },
  'cancelRecurringUrl' => {
    'lastUpdated' => '1216653465',
    'message' => 'Een URL waar de gebruiker een terugkerende transactie kan annuleren.'
  },
  'cart checkout minimum' => {
    'lastUpdated' => '1239953931',
    'message' => 'Minimaal betalingsbedrag'
  },
  'cart checkout minimum help' => {
    'lastUpdated' => '1239954019',
    'message' => 'Vul hier een minimaal winkelwagen bedrag in. Winkelwagens met een kleiner bedrag worden niet toegestaan om af te rekenen.'
  },
  'cart template' => {
    'lastUpdated' => '1216653475',
    'message' => 'Winkelwagen sjabloon'
  },
  'cart template help' => {
    'lastUpdated' => '1216653599',
    'message' => 'Dit sjabloon bepaalt hoe de winkelwagen eruit zal zien.'
  },
  'cashier' => {
    'lastUpdated' => '1231192145',
    'message' => 'Kassa'
  },
  'checkout button' => {
    'lastUpdated' => '1216719505',
    'message' => 'Afrekenen'
  },
  'checkoutButton help' => {
    'lastUpdated' => '1216719547',
    'message' => 'De knop de de gebruiker verwijst naar het scherm waar een betalingsmethode gekozen kan worden.'
  },
  'choose payment gateway message' => {
    'lastUpdated' => '1216719562',
    'message' => 'Hoe wilt u betalen?'
  },
  'choose shipping button' => {
    'lastUpdated' => '1225914512',
    'message' => 'Kies verzendadres'
  },
  'chooseShippingButton help' => {
    'lastUpdated' => '1216719624',
    'message' => 'De gebruiker kan een verzendadres uit het adresboek kiezen wanneer op deze knop gedrukt wordt.'
  },
  'city' => {
    'lastUpdated' => '1226910747',
    'message' => 'Plaats'
  },
  'city help' => {
    'lastUpdated' => '1216724259',
    'message' => 'De plaats die bij dit adres hoort.'
  },
  'cityField help' => {
    'lastUpdated' => '1216724277',
    'message' => 'Een veld dat de plaats van dit adres bevat.'
  },
  'code' => {
    'lastUpdated' => '1213968376',
    'message' => 'Postcode'
  },
  'code help' => {
    'lastUpdated' => '1216724291',
    'message' => 'De postcode van dit adres.'
  },
  'codeField help' => {
    'lastUpdated' => '1216724308',
    'message' => 'Een veld dat de postcode van dit adres bevat.'
  },
  'company url' => {
    'lastUpdated' => '1218182775',
    'message' => 'Bedrijfs URL'
  },
  'configuredTitle' => {
    'lastUpdated' => '1216724362',
    'message' => 'De geconfigureerde titel van dit assetId. Dit is de normale titel van het asset met toegevoegde aanpassingen van de gebruiker.'
  },
  'configuredTitle help' => {
    'lastUpdated' => '1216724390',
    'message' => 'De naam van het object zoals deze geconfigureerd is voor de verkoop.'
  },
  'continue shopping button' => {
    'lastUpdated' => '1216724400',
    'message' => 'Ga verder met winkelen'
  },
  'continueShoppingButton help' => {
    'lastUpdated' => '1216724435',
    'message' => 'Wanneer de gebruiker op deze knop drukt, wordt de gebruiker terug naar de site gebracht.'
  },
  'copy from home address' => {
    'lastUpdated' => '1247061959',
    'message' => 'Kopiëer thuisadres van profiel'
  },
  'copy from work address' => {
    'lastUpdated' => '1247061983',
    'message' => 'Kopiëer werkadres van profiel'
  },
  'country' => {
    'lastUpdated' => '1213631787',
    'message' => 'Land'
  },
  'country help' => {
    'lastUpdated' => '1213968539',
    'message' => 'Het land dat bij dit adres hoort.'
  },
  'countryField help' => {
    'lastUpdated' => '1216653622',
    'message' => 'Een veld dat het land voor dit adres bevat.'
  },
  'coupon' => {
    'lastUpdated' => '1213968481',
    'message' => 'Kortingsbon'
  },
  'current credit message' => {
    'lastUpdated' => '1274108279',
    'message' => '%s heeft een krediet van %s.'
  },
  'date' => {
    'lastUpdated' => '1213631807',
    'message' => 'Datum'
  },
  'date created' => {
    'lastUpdated' => '1215446225',
    'message' => 'Datum aanmaken'
  },
  'dateAdded help' => {
    'lastUpdated' => '1216724474',
    'message' => 'De datum en tijd waarop dit object in de winkelwagen gestopt is.'
  },
  'dateOfPurchase' => {
    'lastUpdated' => '1216652885',
    'message' => 'De datum waarop de aanschaf gedaan is.'
  },
  'default' => {
    'lastUpdated' => '1227603948',
    'message' => 'Stel standaardwaarde in.'
  },
  'defaultButton help' => {
    'lastUpdated' => '1227603988',
    'message' => 'Een knop waarmee de gebruiker een adres als standaard kan aanmerken.'
  },
  'delete' => {
    'lastUpdated' => '1213631797',
    'message' => 'Verwijderen'
  },
  'deleteButton help' => {
    'lastUpdated' => '1213968570',
    'message' => 'Een knop waarmee de gebruiker een bestaand adres kan verwijderen.'
  },
  'deschedule all button' => {
    'lastUpdated' => '1248165287',
    'message' => 'Verwijder alles uit schema'
  },
  'edit' => {
    'lastUpdated' => '1213631776',
    'message' => 'Bewerken'
  },
  'edit address template' => {
    'lastUpdated' => '1216653665',
    'message' => 'Adres bewerk sjabloon'
  },
  'edit address template help' => {
    'lastUpdated' => '1271749683',
    'message' => 'Dit sjabloon bepaalt hoe de invoervelden van het adres eruit zullen zien.'
  },
  'editButton help' => {
    'lastUpdated' => '1216724547',
    'message' => 'Een knop waarmee de gebruiker een bestaand adres mee kan bewerken.'
  },
  'email' => {
    'lastUpdated' => '1225914524',
    'message' => 'E-mail'
  },
  'emailField help' => {
    'lastUpdated' => '1278062352',
    'message' => 'Een veld met het e-mailadres van dit adres.'
  },
  'empty cart' => {
    'lastUpdated' => '1219727781',
    'message' => 'Momenteel is de winkelwagen leeg.'
  },
  'error help' => {
    'lastUpdated' => '1216653648',
    'message' => 'Als er problemen zijn zal de foutmelding hier getoond worden.'
  },
  'export' => {
    'lastUpdated' => '1213970704',
    'message' => 'Exporteren'
  },
  'export tax' => {
    'lastUpdated' => '1218182743',
    'message' => 'Exportbelastingen'
  },
  'extended price' => {
    'lastUpdated' => '1286873319',
    'message' => 'Totaalprijs'
  },
  'extendedPrice help' => {
    'lastUpdated' => '1216724730',
    'message' => 'Het resultaat van de prijs maal het aantal.'
  },
  'firstName' => {
    'lastUpdated' => '1218182713',
    'message' => 'Voornaam'
  },
  'formFooter help' => {
    'lastUpdated' => '1216728095',
    'message' => 'De onderkant van het formulier.'
  },
  'formHeader help' => {
    'lastUpdated' => '1216728109',
    'message' => '<p>De bovenkant van het formulier. </p>'
  },
  'fourweekly' => {
    'lastUpdated' => '1213970719',
    'message' => 'Vier weken'
  },
  'group label' => {
    'lastUpdated' => '1247062022',
    'message' => 'Label'
  },
  'group rate' => {
    'lastUpdated' => '1247062033',
    'message' => 'BTW tarief'
  },
  'halfyearly' => {
    'lastUpdated' => '1213968580',
    'message' => 'Half jaar'
  },
  'hasShippingAddress help' => {
    'lastUpdated' => '1213971510',
    'message' => 'Een functie die aangeeft of de gebruiker al een verzendadres heeft opgegeven. Dit adres is altijd nodig om belastingen te berekenen.'
  },
  'import' => {
    'lastUpdated' => '1213968590',
    'message' => 'Importeren'
  },
  'import successful' => {
    'lastUpdated' => '1213968607',
    'message' => 'Uw producten zijn geimporteerd.'
  },
  'import tax' => {
    'lastUpdated' => '1218182733',
    'message' => 'Importbelastingen'
  },
  'in shop credit' => {
    'lastUpdated' => '1216728538',
    'message' => 'Winkelkrediet'
  },
  'in shop credit used' => {
    'lastUpdated' => '1216728577',
    'message' => 'Gebruikt winkelkrediet'
  },
  'inShopCreditAvailable help' => {
    'lastUpdated' => '1216728665',
    'message' => 'Het winkelkrediet van de gebruiker.'
  },
  'inShopCreditDeduction help' => {
    'lastUpdated' => '1216729243',
    'message' => 'Het winkelkrediet dat gebruikt is in deze bestelling.'
  },
  'is a required field' => {
    'lastUpdated' => '1213971570',
    'message' => '%s is een verplicht veld.'
  },
  'isCashier' => {
    'lastUpdated' => '1231192182',
    'message' => 'Een waar/niet waar functie die waar is als de huidige gebruiker een kassa kan beheren in de winkel.'
  },
  'isRecurring' => {
    'lastUpdated' => '1213971627',
    'message' => 'Een functie die aangeeft of dit een terugkerende transactie is.'
  },
  'isShippable help' => {
    'lastUpdated' => '1216729282',
    'message' => 'Een functie die aangeeft of aan het object een verzendadres gekoppeld kan worden.'
  },
  'isSuccessful' => {
    'lastUpdated' => '1216729639',
    'message' => 'Of deze transactie wel of niet geheel afgerond is.'
  },
  'isUnique help' => {
    'lastUpdated' => '1216729678',
    'message' => 'Een functie die aangeeft of dit object uniek is wat zou resulteren in een maximum hoeveelheid van 1.'
  },
  'item' => {
    'lastUpdated' => '1216729700',
    'message' => 'Object'
  },
  'item assetId' => {
    'lastUpdated' => '1216729717',
    'message' => 'Het assetId van dit object.'
  },
  'item extendedPricePlusTax help' => {
    'lastUpdated' => '1280492298',
    'message' => 'De hoeveelheid BTW plus de prijs van het item maal de hoeveelheid items in de winkelwagen. Deze variabele heeft alleen een waarde als de huidige gebruiker niet de Bezoeker gebruiker is.'
  },
  'item lastUpdated' => {
    'lastUpdated' => '1216730339',
    'message' => 'De datum waarop dit tranactie item het laatst vernieuwd is.'
  },
  'item name help' => {
    'lastUpdated' => '1216730358',
    'message' => 'De naam of titel van het product.'
  },
  'item options' => {
    'lastUpdated' => '1216730425',
    'message' => 'JSON gecodeerde opties voor het asset. Het is waarschijnlijk verstandig deze sjabloon variabele niet te gebruiken.'
  },
  'item price' => {
    'lastUpdated' => '1216730460',
    'message' => 'De ongeformatteerde prijs van deze SKU.'
  },
  'item pricePlusTax help' => {
    'lastUpdated' => '1280492292',
    'message' => 'De hoeveelheid BTW plus de prijs van het item. Deze variabele heeft alleen een waarde als de huidige gebruiker niet de Bezoeker gebruiker is.'
  },
  'item quantity' => {
    'lastUpdated' => '1226910763',
    'message' => 'De hoeveelheid van deze SKU die aangeschaft is.'
  },
  'item shipToButton help' => {
    'lastUpdated' => '1216730557',
    'message' => 'Als op deze knop gedrukt wordt wordt een alternatief adres als verzendadres ingesteld voor dit object.'
  },
  'item shippingAddress1' => {
    'lastUpdated' => '1216652724',
    'message' => 'De eerste regel in een verzendadres met meer regels voor dit object.'
  },
  'item shippingAddress2' => {
    'lastUpdated' => '1216652736',
    'message' => 'De tweede regel in een verzendadres met meer regels voor dit object.<br /> '
  },
  'item shippingAddress3' => {
    'lastUpdated' => '1216652745',
    'message' => 'De derde regel in een verzendadres met meer regels voor dit object.<br /> '
  },
  'item shippingAddressCity' => {
    'lastUpdated' => '1216730599',
    'message' => 'De plaats van het verzendadres van dit object.'
  },
  'item shippingAddressCode' => {
    'lastUpdated' => '1216730610',
    'message' => 'De code van het verzendadres van dit object.<br /> '
  },
  'item shippingAddressCountry' => {
    'lastUpdated' => '1216986373',
    'message' => 'Het land van het verzendadres van dit object.<br /> '
  },
  'item shippingAddressId' => {
    'lastUpdated' => '1216730796',
    'message' => 'De ID van het verzendadres van dit object.'
  },
  'item shippingAddressPhoneNumber' => {
    'lastUpdated' => '1216730821',
    'message' => 'Het telefoonnummer van het verzendadres van dit object.'
  },
  'item shippingAddressState' => {
    'lastUpdated' => '1216730880',
    'message' => 'Het telefoonnummer van het verzendadres van dit object.'
  },
  'item shippingName' => {
    'lastUpdated' => '1216730901',
    'message' => 'De toegekende naam van het verzendadres van dit object.'
  },
  'item taxAmount help' => {
    'lastUpdated' => '1280492315',
    'message' => 'De hoeveelheid BTW bij dit item. Deze variabele heeft alleen een waarde als de huidige gebruiker niet de Bezoeker gebruiker is.'
  },
  'item taxRate help' => {
    'lastUpdated' => '1280492333',
    'message' => 'Het BTW tarief van dit item. Deze variabele heeft alleen een waarde als de huidige gebruiker niet de Bezoeker gebruiker is.'
  },
  'item transactionId' => {
    'lastUpdated' => '1216730933',
    'message' => 'De ID van de tranactie waaronder dit object valt.'
  },
  'item url help' => {
    'lastUpdated' => '1216730972',
    'message' => 'Het URL waar dit object bekeken kan worden zoals het geconfigureerd is.'
  },
  'item vendorId' => {
    'lastUpdated' => '1216730996',
    'message' => 'De ID van de verkoper van dit object.'
  },
  'itemAddressChooser help' => {
    'lastUpdated' => '1280492396',
    'message' => 'Een uitklapmenu voor het kiezen van een adres voor een los product.'
  },
  'itemId' => {
    'lastUpdated' => '1216731091',
    'message' => 'De unieke identificatie van dit object temidden van alle items in alle transacties.'
  },
  'itemShippingAddress' => {
    'lastUpdated' => '1216731236',
    'message' => 'Het aangepaste verzendadres voor dit object.'
  },
  'items' => {
    'lastUpdated' => '1216731268',
    'message' => 'Een functie die alle objecten bevat die geassocieerd worden met deze transactie.'
  },
  'items loop help' => {
    'lastUpdated' => '1216732096',
    'message' => 'Een functie met de variabelen van elk object in de winkelwagen.'
  },
  'label' => {
    'lastUpdated' => '1213968331',
    'message' => 'Label'
  },
  'label help' => {
    'lastUpdated' => '1216734273',
    'message' => 'Voorbeeld: &quot;Thuis&quot; of &quot;Werk&quot;.'
  },
  'lastName' => {
    'lastUpdated' => '1218182752',
    'message' => 'Achternaam'
  },
  'login message' => {
    'lastUpdated' => '1216734319',
    'message' => 'U moet ingelogd zijn om af te rekenen. Klik <a href="%s">hier</a> om in te loggen.'
  },
  'loginFormButton help' => {
    'lastUpdated' => '1280492432',
    'message' => 'Een knop voor het indienen van het login formulier. Deze variabele heeft alleen een waarde als de huidige gebruiker niet de Bezoeker gebruiker is.'
  },
  'loginFormFooter help' => {
    'lastUpdated' => '1280492448',
    'message' => 'Het einde van het login formulier. Deze variabele heeft alleen een waarde als de huidige gebruiker niet de Bezoeker gebruiker is.'
  },
  'loginFormHeader help' => {
    'lastUpdated' => '1280492464',
    'message' => 'Het begin van het login formulier. Deze variabele heeft alleen een waarde als de huidige gebruiker niet de Bezoeker gebruiker is.'
  },
  'loginFormPassword help' => {
    'lastUpdated' => '1280492504',
    'message' => 'Een tekstveld waar de gebruiker het wachtwoord verborgen in kan voeren. Deze variabele heeft alleen een waarde als de huidige gebruiker niet de Bezoeker gebruiker is.'
  },
  'loginFormUsername help' => {
    'lastUpdated' => '1280492531',
    'message' => 'Een tekstveld waar de gebruiker de naam in kan voeren. Deze variabele heeft alleen een waarde als de huidige gebruiker niet de Bezoeker gebruiker is.'
  },
  'manage' => {
    'lastUpdated' => '1213968361',
    'message' => '<p>Beheren </p>'
  },
  'manage my purchases template' => {
    'lastUpdated' => '1216734339',
    'message' => 'Beheer mijn aankopen sjabloon'
  },
  'manage my purchases template help' => {
    'lastUpdated' => '1216734365',
    'message' => 'Dit sjabloon toont informatie over transacties aan de gebruiker.'
  },
  'message help' => {
    'lastUpdated' => '1280492560',
    'message' => 'Wanneer de winkelwagen leeg is, wordt dit bericht getoond aan de gebruiker.'
  },
  'minicart template' => {
    'lastUpdated' => '1216734379',
    'message' => 'Miniwinkelwagen sjabloon'
  },
  'minicart template help' => {
    'lastUpdated' => '1216734412',
    'message' => 'De volgende variablen zijn beschikbaar in het sjabloon van het Miniwinkelwagen macro.'
  },
  'minimumCartAmount help' => {
    'lastUpdated' => '1280492606',
    'message' => 'De minimale hoeveelheid met twee decimalen, zoals dit in de instellingen is ingesteld.'
  },
  'mixed items warning' => {
    'lastUpdated' => '1216734579',
    'message' => 'U kunt niet afrekenen met terugkomende en eenmalige aankopen in de winkelwagen. U kunt &oacute;f &eacute;&eacute;n terugkerend object &oacute;f eenmalige objecten zoveel als gewenst in de winkelwagen hebben tijdens het afrekenen. Als er van beide soorten aankopen gedaan moeten worden kan dit gedaan worden met verschillende transacties.'
  },
  'monthly' => {
    'lastUpdated' => '1213968337',
    'message' => 'Maand'
  },
  'my purchases' => {
    'lastUpdated' => '1216734590',
    'message' => 'Mijn aankopen'
  },
  'my purchases detail template' => {
    'lastUpdated' => '1216734666',
    'message' => 'Gedetailleerd mijn aankopen sjabloon'
  },
  'my purchases detail template help' => {
    'lastUpdated' => '1216734824',
    'message' => 'Welk sjabloon moet gebruikt worden voor het tonen van de gedetailleerde bestellingsgeschiedenis van een gebruiker? Dit zijn individuele aankopen in plaats van de hele transactielijst.'
  },
  'my purchases template' => {
    'lastUpdated' => '1216734781',
    'message' => 'Mijn aankopen sjabloon'
  },
  'my purchases template help' => {
    'lastUpdated' => '1216734813',
    'message' => 'Welk sjabloon moet gebruikt worden voor het tonen van de bestellingsgeschiedenis van een gebruiker?'
  },
  'name' => {
    'lastUpdated' => '1213968324',
    'message' => 'Naam'
  },
  'name help' => {
    'lastUpdated' => '1216734839',
    'message' => 'De naam van de persoon op dit adres.'
  },
  'no billing address' => {
    'lastUpdated' => '1274108435',
    'message' => 'Vul alstublieft een factuuradres in, of kies een adres.'
  },
  'no shipping address' => {
    'lastUpdated' => '1274108451',
    'message' => 'Vul alstublieft een verzendadres in, of kies een adres.'
  },
  'not applicable' => {
    'lastUpdated' => '1216734853',
    'message' => 'Niet toepasbaar'
  },
  'not scheduled payout amount' => {
    'lastUpdated' => '1247062063',
    'message' => 'Niet geplanned voor betaling'
  },
  'notes' => {
    'lastUpdated' => '1213968317',
    'message' => 'Aantekeningen bij deze transactie'
  },
  'notice' => {
    'lastUpdated' => '1216734877',
    'message' => 'Een bericht dat het systeem toont aan de gebruiker.'
  },
  'order for' => {
    'lastUpdated' => '1227629378',
    'message' => 'Bestelling is voor'
  },
  'order number' => {
    'lastUpdated' => '1216734889',
    'message' => 'Bestelling #'
  },
  'order status' => {
    'lastUpdated' => '1216734902',
    'message' => 'Bestellingsstatus'
  },
  'orderNumber' => {
    'lastUpdated' => '1216734926',
    'message' => 'Een normaal leesbaar nummer van de transactie.'
  },
  'orderStatus' => {
    'lastUpdated' => '1215446484',
    'message' => 'De status van dit object: Verzonden, Geannuleerd, Afgezegd of Niet verzonden.'
  },
  'organization' => {
    'lastUpdated' => '1225914540',
    'message' => 'Organisatie'
  },
  'organization help' => {
    'lastUpdated' => '1227604039',
    'message' => 'De naam van een organisatie die dit adres gebruikt. Waarschijnlijk het adres van de werkplek.'
  },
  'originatingTransactionId' => {
    'lastUpdated' => '1216734985',
    'message' => 'Als de transactie een terugkerende transactie is, zal dit de transactie identificatie van de originele aankoop bevatten.'
  },
  'payment address' => {
    'lastUpdated' => '1216652500',
    'message' => 'Factuuradres'
  },
  'payment method' => {
    'lastUpdated' => '1216652511',
    'message' => 'Betalingsmethode'
  },
  'payment methods' => {
    'lastUpdated' => '1216652527',
    'message' => 'Betalingsmethodes'
  },
  'paymentAddress' => {
    'lastUpdated' => '1216652483',
    'message' => 'Aangepast factuuradres'
  },
  'paymentAddress1' => {
    'lastUpdated' => '1216652300',
    'message' => 'De eerste regel in een factuuradres met meer regels.'
  },
  'paymentAddress2' => {
    'lastUpdated' => '1216652312',
    'message' => 'De tweede regel in een factuuradres met meer regels.<br /> '
  },
  'paymentAddress3' => {
    'lastUpdated' => '1216652323',
    'message' => 'De derde regel in een factuuradres met meer regels.<br /> '
  },
  'paymentAddressCity' => {
    'lastUpdated' => '1216652338',
    'message' => 'De plaats van het factuuradres.'
  },
  'paymentAddressCode' => {
    'lastUpdated' => '1216652354',
    'message' => 'De code van het factuuradres.'
  },
  'paymentAddressCountry' => {
    'lastUpdated' => '1216986386',
    'message' => 'Het land van het factuuradres.<br /> '
  },
  'paymentAddressId' => {
    'lastUpdated' => '1216652555',
    'message' => 'Het ID van het factuuradres voor deze transactie.'
  },
  'paymentAddressName' => {
    'lastUpdated' => '1216652570',
    'message' => 'De naam die toegkend is aan het factuuradres.'
  },
  'paymentAddressPhoneNumber' => {
    'lastUpdated' => '1216652587',
    'message' => 'Het telefoonnummer van het factuuradres.'
  },
  'paymentAddressState' => {
    'lastUpdated' => '1216652610',
    'message' => 'De staat of provincie van het factuuradres.'
  },
  'paymentOptions help' => {
    'lastUpdated' => '1280492639',
    'message' => 'Een selectielijst die alle betalingsopties van deze bestelling bevat.'
  },
  'per item shipping' => {
    'lastUpdated' => '1216732174',
    'message' => 'Losse objecten verzenden'
  },
  'phone number' => {
    'lastUpdated' => '1216652620',
    'message' => 'Telefoonnummer'
  },
  'phoneNumber help' => {
    'lastUpdated' => '1216732193',
    'message' => 'Het telefoonnummer dat bij dit adres hoort.'
  },
  'phoneNumberField help' => {
    'lastUpdated' => '1216732216',
    'message' => 'Een veld dat het telefoonnummer van dit adres bevat.'
  },
  'posLookupForm' => {
    'lastUpdated' => '1231192248',
    'message' => 'Een formulier waar een gebruiker gebruikers kan zoeken op e-mail adres voor de kassa.'
  },
  'posUserId' => {
    'lastUpdated' => '1227629468',
    'message' => 'De gebruikers Id van de gebruiker die de POS transactie uitvoert.'
  },
  'posUsername' => {
    'lastUpdated' => '1227629481',
    'message' => 'De naam van de gebruiker die de POS transactie uitvoert.'
  },
  'price' => {
    'lastUpdated' => '1213968245',
    'message' => 'Prijs'
  },
  'price help' => {
    'lastUpdated' => '1215446559',
    'message' => 'De prijs van dit object met twee decimalen.'
  },
  'print' => {
    'lastUpdated' => '1213968255',
    'message' => 'Afdrukken'
  },
  'products' => {
    'lastUpdated' => '1215446238',
    'message' => 'Producten'
  },
  'quantity' => {
    'lastUpdated' => '1215446252',
    'message' => 'Hoeveelheid'
  },
  'quantity help' => {
    'lastUpdated' => '1216732255',
    'message' => 'De hoeveelheid waarin dit object is aangeschaft.'
  },
  'quantityField help' => {
    'lastUpdated' => '1216732429',
    'message' => 'Het veld waarin de gebruiker de aan te schaffen hoeveelheid van dit object kan specificeren.'
  },
  'quarterly' => {
    'lastUpdated' => '1215446262',
    'message' => 'Drie maanden'
  },
  'receipt email template' => {
    'lastUpdated' => '1256113024',
    'message' => 'Ontvangstbewijs e-mail sjabloon'
  },
  'receipt email template help' => {
    'lastUpdated' => '1256113070',
    'message' => 'Welk sjabloon moet gebruikt worden om een e-mail te genereren die aan de gebruiker verzonden wordt om hun aankoop te bevestigen?'
  },
  'refund' => {
    'lastUpdated' => '1215446275',
    'message' => 'Terugstorten'
  },
  'registerLink help' => {
    'lastUpdated' => '1280492682',
    'message' => 'Een link waar een gebruiker naartoe kan gaan om te registreren. Deze variabele heeft alleen een waarde als de huidige gebruiker niet de Bezoeker gebruiker is.'
  },
  'remove button' => {
    'lastUpdated' => '1215446283',
    'message' => 'Verwijderen'
  },
  'removeBox help' => {
    'lastUpdated' => '1280492740',
    'message' => 'Een veld dat, wanneer aangevinkt, ervoor zorgt dat een item uit de winkelwagen gehaald kan worden.'
  },
  'removeButton help' => {
    'lastUpdated' => '1216732463',
    'message' => 'Door op deze knop te drukken wordt dit item uit de winkelwagen verwijderd.'
  },
  'required minimum order amount' => {
    'lastUpdated' => '1240381651',
    'message' => 'Minimaal orderbedrag'
  },
  'sale notification group' => {
    'lastUpdated' => '1256113082',
    'message' => 'Verkoop notificatie groep'
  },
  'sale notification group help' => {
    'lastUpdated' => '1256113102',
    'message' => 'Wie moet op de hoogte gehouden worden van nieuwe transacties?'
  },
  'sameShippingAsBilling help' => {
    'lastUpdated' => '1280492973',
    'message' => 'Een veld dat, wanneer aangevinkt, de winkelwagen meedeelt dat het verzend -en factuuradres hetzelfde zijn.'
  },
  'saveButton help' => {
    'lastUpdated' => '1216732492',
    'message' => 'De standaard knop waarmee het formulier wordt opgeslagen.'
  },
  'schedule all button' => {
    'lastUpdated' => '1248165336',
    'message' => 'Zet alles in schema'
  },
  'scheduled payout amount' => {
    'lastUpdated' => '1248165356',
    'message' => 'Totaalbedrag voor uitbetalingen'
  },
  'search for email' => {
    'lastUpdated' => '1227629492',
    'message' => 'Zoek naar e-mail adres'
  },
  'select gateway template' => {
    'lastUpdated' => '1257329971',
    'message' => 'Selecteer gateway sjabloon'
  },
  'select gateway template help' => {
    'lastUpdated' => '1257329999',
    'message' => 'Dit sjabloon is het sjabloon voor de stap waarin de betalingsmethode gekozen wordt.'
  },
  'ship to button' => {
    'lastUpdated' => '1216652637',
    'message' => 'Verzenden aan'
  },
  'shipToButton help' => {
    'lastUpdated' => '1216732513',
    'message' => 'Doet hetzelfde als de chooseShippingButton.'
  },
  'shippableItemsInCart' => {
    'lastUpdated' => '1274108499',
    'message' => 'Een functie die waar is als er minimaal een object in de winkelwagen zit, dat verzonden moet worden.'
  },
  'shipping' => {
    'lastUpdated' => '1215446672',
    'message' => 'Verzenden'
  },
  'shipping address' => {
    'lastUpdated' => '1215446683',
    'message' => 'Verzend adres'
  },
  'shipping address1' => {
    'lastUpdated' => '1274108529',
    'message' => 'Vul aub een straatnaam en huisnummer in voor het verzendadres.'
  },
  'shipping amount' => {
    'lastUpdated' => '1284129924',
    'message' => 'Verzendkosten'
  },
  'shipping city' => {
    'lastUpdated' => '1274108540',
    'message' => 'Vul aub de stad in voor het verzendadres.'
  },
  'shipping code' => {
    'lastUpdated' => '1274108552',
    'message' => 'Vul aub de postcode in voor het verzendadres.'
  },
  'shipping country' => {
    'lastUpdated' => '1274108561',
    'message' => 'Vul aub het land in voor het verzendadres.'
  },
  'shipping firstName' => {
    'lastUpdated' => '1274108570',
    'message' => 'Vul aub de voornaam in voor het verzendadres.'
  },
  'shipping label' => {
    'lastUpdated' => '1274108582',
    'message' => 'Vul aub de referentie in voor het verzendadres.'
  },
  'shipping lastName' => {
    'lastUpdated' => '1274108591',
    'message' => 'Vul aub de achternaam in voor het verzendadres.'
  },
  'shipping method' => {
    'lastUpdated' => '1215446585',
    'message' => 'Verzend methode'
  },
  'shipping methods' => {
    'lastUpdated' => '1215446574',
    'message' => 'Verzend methodes'
  },
  'shipping phoneNumber' => {
    'lastUpdated' => '1274108603',
    'message' => 'Vul aub het telefoonnummer in voor het verzendadres.'
  },
  'shipping state' => {
    'lastUpdated' => '1274108616',
    'message' => 'Vul aub de staat of provincie in voor het verzendadres.'
  },
  'shippingAddress help' => {
    'lastUpdated' => '1215446749',
    'message' => 'Het verzend adres in HTML.'
  },
  'shippingAddress1' => {
    'lastUpdated' => '1216651595',
    'message' => 'De eerste regel in een verzendadres met meer regels.'
  },
  'shippingAddress2' => {
    'lastUpdated' => '1216651605',
    'message' => 'De tweede regel in een verzendadres met meer regels.<br /> '
  },
  'shippingAddress3' => {
    'lastUpdated' => '1216651614',
    'message' => 'De derde regel in een verzendadres met meer regels.<br /> '
  },
  'shippingAddressChooser help' => {
    'lastUpdated' => '1280493025',
    'message' => 'Een uitklapmenu voor het kiezen van het stanaard verzendadres voor alle items in de iwnkelwagen. Bevat ook acties voor het bewerken en toevoegen van adressen.'
  },
  'shippingAddressCity' => {
    'lastUpdated' => '1216651632',
    'message' => 'De plaats van het verzendadres.'
  },
  'shippingAddressCode' => {
    'lastUpdated' => '1216651647',
    'message' => 'De code van het verzendadres.'
  },
  'shippingAddressCountry' => {
    'lastUpdated' => '1216986391',
    'message' => 'Het land van het verzendadres.'
  },
  'shippingAddressId' => {
    'lastUpdated' => '1216651684',
    'message' => 'De ID van het verzendadres van deze transactie.<br /> '
  },
  'shippingAddressName' => {
    'lastUpdated' => '1216651981',
    'message' => 'De naam die toegekend is aan het verzendadres.'
  },
  'shippingAddressPhoneNumber' => {
    'lastUpdated' => '1216652033',
    'message' => 'Het telefoonnummer van het verzendadres.'
  },
  'shippingAddressState' => {
    'lastUpdated' => '1216652049',
    'message' => 'De staat of provincie van het verzendadres.'
  },
  'shippingDriverId' => {
    'lastUpdated' => '1216652093',
    'message' => 'De unieke identificatie van de verzendmethode van deze transactie.'
  },
  'shippingDriverLabel' => {
    'lastUpdated' => '1216652118',
    'message' => 'Het label van de verzendmethode voor deze transactie.'
  },
  'shippingOptions help' => {
    'lastUpdated' => '1216652164',
    'message' => 'Een selectielijst die alle geconfigureerde verzendmethodes voor deze bestelling bevat.'
  },
  'shippingPrice help' => {
    'lastUpdated' => '1216652183',
    'message' => 'De verzendkosten, met twee decimalen.'
  },
  'shop' => {
    'lastUpdated' => '1213968235',
    'message' => 'Winkel'
  },
  'shop notice' => {
    'lastUpdated' => '1216732981',
    'message' => 'Winkel nieuwsbrief'
  },
  'shop settings' => {
    'lastUpdated' => '1216732990',
    'message' => 'Winkel instellingen'
  },
  'shopCreditDeduction' => {
    'lastUpdated' => '1216733025',
    'message' => 'Het ongeformatteerde winkelkrediet van deze tranactie.'
  },
  'state' => {
    'lastUpdated' => '1213968226',
    'message' => 'Staat / Provincie'
  },
  'state help' => {
    'lastUpdated' => '1216651510',
    'message' => 'De staat of provincie van dit adres.'
  },
  'stateField help' => {
    'lastUpdated' => '1216733306',
    'message' => 'Een veld dat de staat of provincie van dit adres bevat.'
  },
  'status code' => {
    'lastUpdated' => '1216733316',
    'message' => 'Status code'
  },
  'status message' => {
    'lastUpdated' => '1216733324',
    'message' => 'Status bericht'
  },
  'statusCode' => {
    'lastUpdated' => '1216733364',
    'message' => 'De status code die teruggezonden werd door de betalingsinstantie tijdens het verwerken van de opdracht.'
  },
  'statusMessage' => {
    'lastUpdated' => '1216733414',
    'message' => 'Het uitgebreide status bericht dat door de betalingsinstantie teruggezonden werd tijdens het verwerken van de betaling.'
  },
  'submit scheduled payouts button' => {
    'lastUpdated' => '1248165513',
    'message' => 'Uitbetalingen in schema uitvoeren'
  },
  'subtotal' => {
    'lastUpdated' => '1213968215',
    'message' => 'Subtotaal'
  },
  'subtotalPrice help' => {
    'lastUpdated' => '1216733437',
    'message' => 'Het totaalbedrag van alle objecten in de winkewagen.'
  },
  'tax' => {
    'lastUpdated' => '1213968160',
    'message' => 'BTW'
  },
  'tax help' => {
    'lastUpdated' => '1216719789',
    'message' => 'Het bedrag aan belastingen voor de gehele inhoud van de winkelwagen.'
  },
  'taxes' => {
    'lastUpdated' => '1213968168',
    'message' => 'Belastingen'
  },
  'taxes help' => {
    'lastUpdated' => '1216651567',
    'message' => 'Het bedrag aan BTW van deze transactie, met twee decimalen.'
  },
  'thank you message' => {
    'lastUpdated' => '1216719893',
    'message' => 'Bedankt voor uw bestelling!. Bewaar dit als uw ontvangstbon.'
  },
  'too many of this item' => {
    'lastUpdated' => '1213968202',
    'message' => 'Kan niet zo veel %s aan de winkelwagen toevoegen'
  },
  'total' => {
    'lastUpdated' => '1213968146',
    'message' => 'Totaal'
  },
  'totalItems help' => {
    'lastUpdated' => '1216733455',
    'message' => 'Het totaal aantal objecten in de winkelwagen.'
  },
  'totalPrice help' => {
    'lastUpdated' => '1216733491',
    'message' => 'Het totale bedrag dat afgerekend zou moeten worden met de huidige vulling van de winkelwagen.'
  },
  'tracking number' => {
    'lastUpdated' => '1216735033',
    'message' => 'Tracking #'
  },
  'transaction id' => {
    'lastUpdated' => '1216733976',
    'message' => 'Transactie ID'
  },
  'transactionCode' => {
    'lastUpdated' => '1216734015',
    'message' => 'Tranactie code of ID die doorgegeven wordt door de betalingsinstantie. Niet alle instanties ondersteunen dit.'
  },
  'transactionId' => {
    'lastUpdated' => '1216734033',
    'message' => 'De unieke identificatie van de transactie.'
  },
  'transactions' => {
    'lastUpdated' => '1213968114',
    'message' => 'Transacties'
  },
  'update' => {
    'lastUpdated' => '1213967823',
    'message' => 'Bijwerken'
  },
  'update cart button' => {
    'lastUpdated' => '1216652207',
    'message' => 'Winkelwagen bijwerken'
  },
  'updateButton help' => {
    'lastUpdated' => '1216734075',
    'message' => 'Door op deze knop te drukken worden de veranderingen die aan de winkelwagen gedaan zijn toegepast en de prijzen worden herberekend.'
  },
  'use same shipping as billing' => {
    'lastUpdated' => '1274108657',
    'message' => 'Gebruik het verzendadres als factuuradres.'
  },
  'use this address' => {
    'lastUpdated' => '1216734084',
    'message' => 'Gebruik dit adres'
  },
  'useButton help' => {
    'lastUpdated' => '1216734118',
    'message' => 'Een knop waarmee de gebruiker een bestaand adres kan kiezen voor het gebruik in een formulier.'
  },
  'userId' => {
    'lastUpdated' => '1216719821',
    'message' => 'De gebruikers ID van de gebruiker die deze transactie heeft uitgevoerd.'
  },
  'userIsVisitor help' => {
    'lastUpdated' => '1278062392',
    'message' => 'Een functie die waar is wanneer de huidige gebruiker de Bezoeker gebruiker is.'
  },
  'username' => {
    'lastUpdated' => '1213968124',
    'message' => 'Gebruiker'
  },
  'username help' => {
    'lastUpdated' => '1216652251',
    'message' => 'De naam van de gebruiker die deze transactie heeft uitgevoerd, zodat deze niet meer opgezocht hoeft te worden.'
  },
  'vendor id' => {
    'lastUpdated' => '1247066713',
    'message' => 'Verkoper Id'
  },
  'vendor name' => {
    'lastUpdated' => '1247066721',
    'message' => 'Naam verkoper'
  },
  'vendor payouts' => {
    'lastUpdated' => '1247066739',
    'message' => 'Verkoper betalingen'
  },
  'vendors' => {
    'lastUpdated' => '1216734125',
    'message' => 'Verkopers'
  },
  'view cart' => {
    'lastUpdated' => '1213968136',
    'message' => 'Bekijk winkelwagen'
  },
  'view my purchases template' => {
    'lastUpdated' => '1216734139',
    'message' => 'Bekijk mijn aankopen sjabloon'
  },
  'view my purchases template help' => {
    'lastUpdated' => '1216734189',
    'message' => 'Dit sjabloon toont gedetailleerde informatie over transacties aan de gebruiker.'
  },
  'view products' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'viewDetailURL' => {
    'lastUpdated' => '1216734219',
    'message' => 'Een URL waar meer informatie van de transactie getoond wordt.'
  },
  'viewItemUrl' => {
    'lastUpdated' => '1216734248',
    'message' => 'Een URL waar meer informatie over het object uit de transactie geoond wordt.'
  },
  'vp item id' => {
    'lastUpdated' => '1247066698',
    'message' => 'Object ID'
  },
  'vp item payout amount' => {
    'lastUpdated' => '1248165533',
    'message' => 'Bedrag uitbetaling'
  },
  'vp item payout status' => {
    'lastUpdated' => '1248165543',
    'message' => 'Status uitbetaling'
  },
  'vp item price' => {
    'lastUpdated' => '1248165548',
    'message' => 'Prijs'
  },
  'vp item quantity' => {
    'lastUpdated' => '1248165571',
    'message' => 'Aantal'
  },
  'vp item title' => {
    'lastUpdated' => '1248165583',
    'message' => 'Naam object'
  },
  'vp payouts' => {
    'lastUpdated' => '1257330013',
    'message' => 'Uitbetalingen'
  },
  'vp select vendor' => {
    'lastUpdated' => '1257330068',
    'message' => 'Kies een verkoper uit de lijst voor het beheren van individuele uitbetalingen.'
  },
  'vp vendors' => {
    'lastUpdated' => '1257330077',
    'message' => 'Verkopers'
  },
  'weekly' => {
    'lastUpdated' => '1213967834',
    'message' => 'Week'
  },
  'who can manage' => {
    'lastUpdated' => '1213966639',
    'message' => 'Wie kan beheren?'
  },
  'who can manage help' => {
    'lastUpdated' => '1216651536',
    'message' => 'De groep die het commerciesysteem kan beheren.'
  },
  'who is a cashier' => {
    'lastUpdated' => '1231192291',
    'message' => 'Wie kan kassa\'s&nbsp; beheren?'
  },
  'who is a cashier help' => {
    'lastUpdated' => '1231192339',
    'message' => 'Mensen die kassa\'s beheren kunnen aankopen doen namens iemand anders door het e-mail adres in de winkelwagen in te voeren.'
  },
  'yearly' => {
    'lastUpdated' => '1213966624',
    'message' => 'Jaar'
  }
}
;

1;
